StderrStream class
Standard error stream (stderr).
- Inheritance
-
- Object
- PrologStream
- CharacterOutputStream
- StderrStream
Constructors
- StderrStream(IOSink _stderr)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Unique identifier for this stream.
finalinherited
- isBinary → bool
-
Returns true if this is a binary stream.
no setterinherited
- isInput → bool
-
Returns true if this is an input stream.
no setterinherited
- isOpen → bool
-
Returns true if the stream is open.
no setterinherited
- isOutput → bool
-
Returns true if this is an output stream.
no setterinherited
- isText → bool
-
Returns true if this is a text stream.
no setterinherited
- properties → StreamProperties
-
Properties of this stream.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void -
Closes the stream.
inherited
-
flush(
) → void -
Flushes any buffered output.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
writeChar(
String char) → void -
Writes a character.
override
-
writeCode(
int code) → void -
Writes a character code.
override
-
writeNewline(
) → void -
Writes a newline.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited