BuiltinStream class
Built-in succeeded with multiple solutions (non-deterministic).
Provides a stream of substitutions representing different solutions.
- Inheritance
-
- Object
- BuiltinResult
- BuiltinStream
Constructors
-
BuiltinStream(Stream<
Substitution> solutions) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
solutions
→ Stream<
Substitution> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited