FileInputStream class
File-based character input stream.
- Inheritance
-
- Object
- PrologStream
- CharacterInputStream
- FileInputStream
Constructors
- FileInputStream(RandomAccessFile _file, String alias)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Unique identifier for this stream.
finalinherited
- isBinary → bool
-
Returns true if this is a binary stream.
no setterinherited
- isInput → bool
-
Returns true if this is an input stream.
no setterinherited
- isOpen → bool
-
Returns true if the stream is open.
no setterinherited
- isOutput → bool
-
Returns true if this is an output stream.
no setterinherited
- isText → bool
-
Returns true if this is a text stream.
no setterinherited
- properties → StreamProperties
-
Properties of this stream.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → void -
Closes the stream.
override
-
flush(
) → void -
Flushes any buffered output.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
peekChar(
) → String? -
Peeks at the next character without consuming it.
override
-
peekCode(
) → int -
Peeks at the next character code without consuming it.
override
-
readChar(
) → String? -
Reads the next character (returns null at EOF).
override
-
readCode(
) → int -
Reads the next character code (returns -1 at EOF).
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited